Normal

# test doc

first issue

- bit
- bold italic

- orange
- apple

- final

text to separate lists

1. now with numbers
2. the prisoner

1. not an italic number
2. a bold human being

3. end

bold
italic

    def func(x):
      if x < 1:
        return 'a'
      return 'b'

Some `fixed width text` here
`italic fixed width text`

2012. Now that was a good year. So was 2011. That's all.

3.14159 is an approximation of pi.

+ not + a list item

+foo

- foo - bar

-foo

not a header
--

not a hr
---
- - -

c:\tmp, \\server\path, \_/, foo\bar, #\#, \\#